@@ -1,7 +1,6 @@
 from pathlib import Path
 from uuid import uuid4
-import dash_html_components as html
-import dash_core_components as dcc
+from dash import html, dcc
 
 from dash.dependencies import Input, Output
 from everviz.plugins.plugin_abc import EvervizPluginABC
